%plot_UK_inflation

function plot_UK_inflation

%Year limits
start_year = 1920;
end_year = 2020;

%For SCALE equivalent at YEAR
YEAR = 2012;
SCALE = 100;

%Fontsize
fsize = 18;

%

%Get UK inflation data
load UK_inflation

%Plot UK inflation data
figure('color',[1 1 1])

%Guardian DataBlog 219
plot( G09.years_since_1Jan_1948+1948, G09.RPI,'r',...
    G09.years_since_1Jan_1948+1948, G09.CPI,'g',...
    G09.years_since_1Jan_1948+1948, G09.RPIJ,'m',...
    G09.years_since_1Jan_1948+1948, G09.CPIH,'k');
hold on;

%Since 1752
plot( CPI_since_1752.year, CPI_since_1752.inflation_rate,'b--');

%UK inflation trends to 2019
plot( UK2019.year, UK2019.inflation_rate*100,'b');

%Axis labels etc
xlabel('Year','fontsize',fsize );
ylabel('UK inflation rate %','fontsize',fsize );
title('UK inflation rate','fontsize',fsize );
if end_year>1900
    legend({'G09 RPI','G09  CPI','G09  RPIJ',...
        'G09 CPIH','Since 1752','UK2019'},'fontsize',fsize,'location','northeast' );
end
xlim( [start_year,end_year] );
set(gca,'fontsize',fsize )
grid on;
print(gcf,['UK inflation ',num2str(start_year),'-',num2str(end_year)],'-dpng','-r300');
close(gcf);

%%

%Plot UK 2012 100 equivalent
figure('color',[1 1 1])

%Guardian DataBlog 2009
plot( G09.pounds_1948_years,...
    scale_by_year( G09.pounds_1948_years, G09.pounds_1948,YEAR,SCALE ), 'r',...
    UK2019.year,...
    scale_by_year( UK2019.year, UK2019.pounds_1948,YEAR,SCALE  ),'b',...
    CPI_since_1752.year,...
    scale_by_year( CPI_since_1752.year, CPI_since_1752.pounds_1948,YEAR,SCALE  ),'b--' );

%Axis labels etc
xlabel('Year','fontsize',fsize );
ylabel('2012 100 equivalent','fontsize',fsize );
title('2012 100 equivalent','fontsize',fsize );
if end_year>1900
    legend({'G09 RPI','UK2019','Since 1752'},'fontsize',fsize,'location','northwest' );
end
xlim( [start_year,end_year] );
set(gca,'fontsize',fsize )
grid on;
print(gcf,['2012 pounds ',num2str(start_year),'-',num2str(end_year)],'-dpng','-r300');
close(gcf);

%%

%Scale by value at a given year
function y = scale_by_year( years, x, year, scale_at_year )
y = x*scale_at_year/interp1( years, x, year );

%End of code