%normal_z_plot
% Function that generates an example plot of the Normal Distribution, and
% the variation of the probability P(z<zbuy) or P(z>zsell) vs zbuy and
% zsell
% LAST UPDATED by Andy French 18/02/2021

function normal_z_plot

%Fontsize for graphs
fsize = 18;

%Number of plot values
N = 1000;

%Plot Normal distribution
Z = 1;
PZ = 0.5 + 0.5*erf( Z/sqrt(2) );
z = linspace(-4,4,N); zZ = linspace(-10,Z,N);
p = (1/sqrt(2*pi))*exp( -0.5*z.^2 ); pZ = (1/sqrt(2*pi))*exp( -0.5*zZ.^2 );
patch( [zZ,fliplr(zZ)],[zeros(1,N),fliplr(pZ)],'g','edgecolor','g','facealpha',0.5 );
hold on; plot(z,p,'b','linewidth',1); xlim([-4,4]);
set(gca,'fontsize',fsize); xlabel('z','fontsize',fsize);
ylabel('p(z)','fontsize',fsize); grid on; box on;
title(['Standardized Normal distribution. P(z<',num2str(Z),')=',num2str(PZ,3)],'fontsize',fsize)
print(gcf,'normal distribution demo.png','-r300','-dpng'); clf;

%Plot P(z<zbuy) or P(z>zsell) vs zbuy and zsell
zbuy = linspace( -6,0,N ); zsell = linspace(0,6,N);
Psell = 0.5 - 0.5*erf( zsell/sqrt(2) ); Pbuy = 0.5 + 0.5*erf( zbuy/sqrt(2) );
semilogy( zbuy,Pbuy,'b',zsell,Psell,'r' );
set(gca,'fontsize',fsize); xlabel('z_{buy} or z_{sell}','fontsize',fsize);
ylabel('Probability','fontsize',fsize); grid on;  box on;
legend( {'P(z<z_{buy})', 'P(z>z_{sell})'},'fontsize',fsize);
title('Normal distribution probability for P(z<z_{buy}) or P(z>z_{sell})','fontsize',fsize)
print(gcf,'P buy and sell.png','-r300','-dpng'); close(gcf);

%End of code